#!/bin/sh
#
# Copyright (C) 2009-2014:
#    Gabes Jean, naparuba@gmail.com
#    Gerhard Lausser, Gerhard.Lausser@consol.de
#    Gregory Starck, g.starck@gmail.com
#    Hartmut Goebel, h.goebel@goebel-consult.de
#
# This file is part of Shinken.
#
# Shinken is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Shinken is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Shinken.  If not, see <http://www.gnu.org/licenses/>.


DIR="$(cd $(dirname "$0"); pwd)"
BIN="$DIR"/../bin
ETC="$DIR"/../etc

echo "Stopping broker"

parent=$(cat /var/run/shinken/brokerd.pid)

kill $parent
sleep 1

# kill parent and childs broker processes
for brokerpid in $(ps -f --ppid $parent | grep "shinken-broker" | awk '{print $2}')
do
    echo "KILLING MODULE BROKER PROCESS" $brokerpid
    kill $brokerpid
done

